@@ -212,22 +212,27 @@ def list_runners(**kwargs) -> Runners | list[dict]:
         kwargs:
             The criteria to filter runners, possible keys are:
 
-            - `backend`
-            - `backend_version`
-            - `backend_version_prefix`
-            - `backend_variant`
-            - `service`
-            - `service_version`
-            - `service_version_prefix`
-            - `platform`
-
-            Also accepts `todict` to return a list of dictionaries instead of Runner objects.
+            - `data_path`: The path to the JSON data file. If not provided, uses the default data file.
+            - `todict`: If True, returns a list of dictionaries instead of Runner objects.
+            - `with_deprecated`: Whether to include deprecated runners, default is True.
+            - `backend`: The backend name, default is None.
+            - `backend_version`: The backend version, default is None.
+            - `backend_version_prefix`: The prefix of the backend version, default is None.
+            - `backend_variant`: The backend variant, default is None.
+            - `service`: The service name, default is None.
+            - `service_version`: The service version, default is None.
+            - `service_version_prefix`: The prefix of the service version, default is None.
+            - `platform`: The platform, default is None.
 
     Returns:
          A list of matching runner.
 
     """
     data_path = resources.files(__package__).joinpath(f"{Path(__file__).name}.json")
+    if "data_path" in kwargs:
+        _data_path: str | Path | None = kwargs.pop("data_path")
+        if _data_path:
+            data_path = Path(_data_path) if isinstance(_data_path, str) else _data_path
     with data_path.open("r", encoding="utf-8") as f:
         json_list = json.load(f)
         runners = [Runner.from_dict(item) for item in json_list]
@@ -236,6 +241,10 @@ def list_runners(**kwargs) -> Runners | list[dict]:
     if not kwargs:
         return convert_runners_to_dict(runners) if todict else runners
 
+    with_deprecated = kwargs.pop("with_deprecated", True)
+    if with_deprecated is None:
+        with_deprecated = True
+
     allowed_keys = {
         "backend",
         "backend_version",
@@ -273,6 +282,8 @@ def list_runners(**kwargs) -> Runners | list[dict]:
                 match = False
                 break
         if match:
+            if not with_deprecated and item.deprecated:
+                continue
             results.append(item)
 
     return convert_runners_to_dict(results) if todict else results
@@ -604,16 +615,17 @@ def list_backend_runners(**kwargs) -> BackendRunners | list[dict]:
         kwargs:
             The criteria to filter backend runners, possible keys are:
 
-            - `backend`
-            - `backend_version`
-            - `backend_version_prefix`
-            - `backend_variant`
-            - `service`
-            - `service_version`
-            - `service_version_prefix`
-            - `platform`
-
-            Also accepts `todict` to return a list of dictionaries instead of BackendRunner objects.
+            - `data_path`: The path to the JSON data file. If not provided, uses the default data file.
+            - `todict`: If True, returns a list of dictionaries instead of BackendRunner objects.
+            - `with_deprecated`: Whether to include deprecated runners, default is True.
+            - `backend`: The backend name, default is None.
+            - `backend_version`: The backend version, default is None.
+            - `backend_version_prefix`: The prefix of the backend version, default is None.
+            - `backend_variant`: The backend variant, default is None.
+            - `service`: The service name, default is None.
+            - `service_version`: The service version, default is None.
+            - `service_version_prefix`: The prefix of the service version, default is None.
+            - `platform`: The platform, default is None.
 
     Returns:
          A list of matching backend runner.
@@ -777,16 +789,17 @@ def list_service_runners(**kwargs) -> ServiceRunners | list[dict]:
         kwargs:
             The criteria to filter service runners, possible keys are:
 
-            - `backend`
-            - `backend_version`
-            - `backend_version_prefix`
-            - `backend_variant`
-            - `service`
-            - `service_version`
-            - `service_version_prefix`
-            - `platform`
-
-            Also accepts `todict` to return a list of dictionaries instead of ServiceRunner objects.
+            - `data_path`: The path to the JSON data file. If not provided, uses the default data file.
+            - `todict`: If True, returns a list of dictionaries instead of ServiceRunner objects.
+            - `with_deprecated`: Whether to include deprecated runners, default is True.
+            - `backend`: The backend name, default is None.
+            - `backend_version`: The backend version, default is None.
+            - `backend_version_prefix`: The prefix of the backend version, default is None.
+            - `backend_variant`: The backend variant, default is None.
+            - `service`: The service name, default is None.
+            - `service_version`: The service version, default is None.
+            - `service_version_prefix`: The prefix of the service version, default is None.
+            - `platform`: The platform, default is None.
 
     Returns:
          A list of matching service runner.
